@@ -4,7 +4,6 @@ import sys
 
 from typing import Any, Dict, List
 
-
 if sys.version_info < (3, 7):
     from collections.abc import MutableMapping
 
@@ -14,12 +13,12 @@ else:
 
     _JsonDictMutableMapping = MutableMapping[str, Any]
 
-__all__ = [
-    "JsonDictT",
-    "JsonListT",
-    "JsonArrT",
-    "JsonObjT",
-]
+__all__ = (
+    'JsonDictT',
+    'JsonListT',
+    'JsonArrT',
+    'JsonObjT',
+)
 
 # Json friendly: Union[None, bool, int, float, str, List[Any], Dict[str, Any]]
 JsonDictT = Dict[str, Any]
